@@ -118,7 +118,8 @@ class Template:
                     args_deleted = re.sub(arg, "\n", ignore_text)
                     # If there is two line breaks, remove one
                     args_cleaned = re.sub("\n\n\n", "\n", args_deleted)
-                    self.gitignore.write_text(args_cleaned)
+                    # Remove line break at the end of the file and save
+                    self.gitignore.write_text(args_cleaned.rstrip("\n"))
         else:
             raise ValueError(
                 "git2ignore: delete_gitignore requires either bool or str!"
